<?php
/**
 * Default theme options
 *
 * @package Education_Soul
 */

if ( ! function_exists( 'education_soul_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function education_soul_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']                 = true;
		$defaults['show_tagline']               = true;
		$defaults['show_ticker']                = true;
		$defaults['ticker_title']               = esc_html__( 'News:', 'education-soul-pro' );
		$defaults['ticker_category']            = 0;
		$defaults['ticker_number']              = 3;
		$defaults['contact_number']             = '987-235-5678';
		$defaults['contact_email']              = 'demo@example.com';
		$defaults['contact_address']            = esc_html__( 'Kathmandu, Nepal', 'education-soul-pro' );
		$defaults['show_social_in_header']      = false;
		$defaults['enable_sticky_primary_menu'] = false;
		$defaults['search_in_header']           = true;
		$defaults['buy_button_text']            = esc_html__( 'Buy Now', 'education-soul-pro' );
		$defaults['buy_button_url']             = '#';

		// Layout.
		$defaults['site_layout']             = 'fluid';
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'excerpt';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Pagination.
		$defaults['pagination_type'] = 'numeric';

		// Content Meta.
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['copyright_text']        = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'education-soul-pro' );
		$defaults['powered_by_text']       = esc_html__( 'Education Soul Pro by ', 'education-soul-pro' ) . '<a target="_blank" rel="designer" href="https://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content']  = false;
		$defaults['show_social_in_footer'] = false;
		$defaults['go_to_top']             = true;

		// Blog.
		$defaults['excerpt_length']     = 40;
		$defaults['read_more_text']     = esc_html__( 'Read more', 'education-soul-pro' );
		$defaults['exclude_categories'] = '';

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Homepage Sections.
		$defaults['homepage_sections'] = array( 'featured-slider', 'call-to-action', 'news-and-events', 'latest-news' );

		// Homepage Call To Action.
		$defaults['cta_title']                 = esc_html__( 'Welcome To Our University', 'education-soul-pro' );
		$defaults['cta_description']           = esc_html__( 'Every undergraduate student is eligible to receive a fellowship of up to $10,000 for a summer internship or faculty-mentored research project. Find your opportunity, make your case for how it fits your academic plans, and we will help fund it.', 'education-soul-pro' );
		$defaults['cta_primary_button_text']   = esc_html__( 'Learn More', 'education-soul-pro' );
		$defaults['cta_primary_button_url']    = '#';
		$defaults['cta_secondary_button_text'] = esc_html__( 'Online Tour', 'education-soul-pro' );
		$defaults['cta_secondary_button_url']  = '#';
		$defaults['cta_background_image']      = '';


		// Homepage News and Events.
		$defaults['news_and_events_ntitle']    = esc_html__( 'News', 'education-soul-pro' );
		$defaults['news_and_events_nnumber']   = 4;
		$defaults['news_and_events_ncategory'] = 0;
		$defaults['news_and_events_etitle']    = esc_html__( 'Events', 'education-soul-pro' );
		$defaults['news_and_events_enumber']   = 4;
		$defaults['news_and_events_ecategory'] = 0;

		// Homepage Services.
		$defaults['services_title']  = esc_html__( 'Services', 'education-soul-pro' );
		$defaults['services_number'] = 6;
		$defaults['services_column'] = 3;

		// Homepage Featured Blocks.
		$defaults['featured_blocks_title']  = esc_html__( 'Featured', 'education-soul-pro' );
		$defaults['featured_blocks_number'] = 3;
		$defaults['featured_blocks_column'] = 3;

		// Homepage Latest News.
		$defaults['latest_news_title']          = esc_html__( 'Latest News', 'education-soul-pro' );
		$defaults['latest_news_layout']         = 1;
		$defaults['latest_news_category']       = 0;
		$defaults['latest_news_number']         = 4;
		$defaults['latest_news_column']         = 4;
		$defaults['latest_news_featured_image'] = 'education-soul-thumb';
		$defaults['latest_news_excerpt_length'] = 20;

		// Homepage Testimonials.
		$defaults['testimonials_title']            = esc_html__( 'Testimonials', 'education-soul-pro' );
		$defaults['testimonials_category']         = 0;
		$defaults['testimonials_number']           = 4;
		$defaults['testimonials_background_image'] = '';

		// Homepage Team.
		$defaults['team_title']    = esc_html__( 'Our Team', 'education-soul-pro' );
		$defaults['team_category'] = 0;
		$defaults['team_number']   = 4;
		$defaults['team_column']   = 4;

		// Homepage Gallery.
		$defaults['gallery_title'] = esc_html__( 'Gallery', 'education-soul-pro' );
		$defaults['gallery_page']  = 0;

		// Homepage Special Page.
		$defaults['special_title'] = esc_html__( 'Title', 'education-soul-pro' );
		$defaults['special_page']  = 0;

		// Font.
		$font_keys = education_soul_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
				$defaults[ $k ] = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Slider Options.
		$defaults['featured_slider_transition_effect']   = 'fadeout';
		$defaults['featured_slider_transition_delay']    = 3;
		$defaults['featured_slider_transition_duration'] = 1;
		$defaults['featured_slider_enable_caption']      = true;
		$defaults['featured_slider_caption_alignment']   = 'left';
		$defaults['featured_slider_enable_arrow']        = true;
		$defaults['featured_slider_enable_pager']        = true;
		$defaults['featured_slider_enable_autoplay']     = false;
		$defaults['featured_slider_type']                = 'demo-slider';
		$defaults['featured_slider_number']              = 2;
		$defaults['featured_slider_category']            = '';
		$defaults['featured_slider_tag']                 = '';
		$defaults['featured_slider_read_more_text']      = esc_html__( 'Read More', 'education-soul-pro' );

		// Color.
		$colors = education_soul_get_default_colors();
		if ( ! empty( $colors ) ) {
			foreach ( $colors as $key => $val ) {
				$defaults[ $key ] = $val;
			}
		}

		// Pass through filter.
		$defaults = apply_filters( 'education_soul_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
